import 'zone.js/dist/zone-node';
import 'reflect-metadata';
import { renderModuleFactory } from '@angular/platform-server';
import { enableProdMode } from '@angular/core';

import * as express from 'express';
import { join } from 'path';
import { readFileSync } from 'fs';

// Faster server renders w/ Prod mode (dev mode never needed)
enableProdMode();

// Express server
const app = express();

const PORT = process.env.PORT || 4000;
const DIST_FOLDER = join(process.cwd(), 'dist');

// Our index.html we'll use as our template
const template = readFileSync(join(DIST_FOLDER, 'browser', 'index.html')).toString();

// * NOTE :: leave this as require() since this file is built Dynamically from webpack
const { AppServerModuleNgFactory, LAZY_MODULE_MAP } = require('./dist/server/main');

// Express Engine
import {ngExpressEngine, RenderOptions} from '@nguniversal/express-engine';
// Import module map for lazy loading
import { provideModuleMap } from '@nguniversal/module-map-ngfactory-loader';
import {REQUEST, RESPONSE} from "@nguniversal/express-engine/tokens";
import {isArray} from "util";

// Our Universal express-engine (found @ https://github.com/angular/universal/tree/master/modules/express-engine)
// app.engine('html', ngExpressEngine({
//   bootstrap: AppServerModuleNgFactory,
//   providers: [
//      { provide: 'request', useFactory: () => options.req, deps: [] },
//     provideModuleMap(LAZY_MODULE_MAP)
//   ]
// }));

// be able to get request and get domain from there

app.engine('html', (_, options: any, callback) => {
  const opts = {
    document: template,
    url: options.req.url,
    extraProviders: [
      provideModuleMap(LAZY_MODULE_MAP),
      {
        provide: REQUEST,
        useValue: options.req
      },
      {
        provide: RESPONSE,
        useValue: options.req.res,
      },
    ]
  };

  renderModuleFactory(AppServerModuleNgFactory, opts)
    .then(html => callback(null, html)
    );
});

app.set('view engine', 'html');
app.set('views', join(DIST_FOLDER, 'browser'));
// Allow frames from specific domains
app.use(function (req, res, next) {
  var XFRAME_WHITELIST = [ 'http://spitoo.di.uoa.gr:5000/','http://scoobydoo.di.uoa.gr:5000/', 'https://beta.admin.connect.openaire.eu/','https://admin.connect.openaire.eu/'  ];
  let referer: string;
  if(req.headers.referer){
    referer = isArray(req.headers.referer)?req.headers.referer[0]:(<string>req.headers.referer);
    referer = referer.split("?")[0];
  }
  if (  referer &&  (XFRAME_WHITELIST.indexOf(referer) != -1 || referer.indexOf("/customize-layout") !=-1 || referer.indexOf(".d4science.org") != -1)) {
    // res.header('X-FRAME-OPTIONS', 'allow from ' +req.headers.referer);
  }else {
    res.header('X-FRAME-OPTIONS', 'SAMEORIGIN');
  }
  next();
});
 // - Serve sitemap based on the host -
  app.get('/sitemap.xml', (req, res) => {
    let host = req.get("host").split(":")[0];
    let connectLinks= ["/","/about/learn-how","/about/learn-in-depth", "/about/faq","/search/find/communities"];
    let communityLinks= ["/","/search/find/research-outcomes?size=20","/search/advanced/research-outcomes?size=20","/participate/deposit/learn-how","/organizations", "/content"];
    let sitemap = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n" +
      "<urlset xmlns=\"http://www.sitemaps.org/schemas/sitemap/0.9\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xsi:schemaLocation=\"http://www.sitemaps.org/schemas/sitemap/0.9 http://www.sitemaps.org/schemas/sitemap/0.9/sitemap.xsd\">";
    let urlPre = "<url>\n" +
      "    <loc>";
    let urlSuf = "</loc>\n" +
      "    </url>";
    for(let link of (host.indexOf("connect.openaire.eu") == -1 ?communityLinks:connectLinks)){
      sitemap += urlPre + "https://" + host + link + urlSuf;
     }
    sitemap += "\n</urlset>";
    res.setHeader('content-type', 'application/xml');
    res.send( sitemap);
  });
app.get('/robots.txt', (req, res) => {
  let host = req.get("host").split(":")[0];
  let robots = "";
  if(host.indexOf(".openaire.eu") != -1 && host.indexOf("beta.") == -1 ){
    //link to disallow
    let connectLinks= ["/about/*","/search/find/communities"];
    let communityLinks= ["/search/advanced/*","/participate/*",
      "/search/project",'/search/result', '/search/publication', '/search/dataset','/search/software','/search/other','/search/dataprovider','/search/organization','/project-report',
      '/search/find/publications','/search/find/datasets','/search/find/software','/search/find/other','/search/find/projects','/search/find/dataproviders','/search/find/research-outcomes'

    ];

    robots = "User-Agent: *\n"+
    "Crawl-delay: 30\n" +
      "Sitemap: /sitemap.xml\n";
    for(let link of (host.indexOf("connect.openaire.eu") == -1 ?connectLinks:communityLinks)){
      robots +=  "Disallow: " + link +  "\n";
    }
  }else{
    robots = "User-Agent: *\n" +
      "Disallow: /\n"
  }
  res.setHeader('content-type', 'text/plain');
  res.send( robots);
});

/* - Example Express Rest API endpoints -
  app.get('/api/**', (req, res) => { });
*/

// Server static files from /browser
app.get('*.*', express.static(join(DIST_FOLDER, 'browser'), {
  maxAge: '1y'
}));

// ALl regular routes use the Universal engine
app.get('*', (req, res) => {
  res.render('index', { req });
});

// Start up the Node server
app.listen(PORT, () => {
  console.log(`Node Express server listening on http://localhost:${PORT}`);
});
